@@ -1,9 +1,10 @@
+use crate::commands::find;
 use config::{Config, ConfigError, File};
 use dirs_next::home_dir;
 use serde::Deserialize;
-use std::{path::PathBuf, sync::Mutex};
+use std::{env, fs, path::PathBuf, sync::Mutex};
 
-use crate::commands::find;
+const CONFIG_FILE_NAMES: [&str; 2] = ["config.yml", "config.yaml"];
 
 #[derive(Debug, Deserialize, Clone)]
 pub struct Settings {
@@ -11,6 +12,19 @@ pub struct Settings {
     pub preview_files: Vec<String>,
     pub preview: bool,
     pub preview_with_bat: bool,
+    pub preview_fallback_exa: bool,
+}
+
+fn is_program_in_path(program: &str) -> bool {
+    if let Ok(path) = env::var("PATH") {
+        for p in path.split(':') {
+            let p_str = format!("{}/{}", p, program);
+            if fs::metadata(p_str).is_ok() {
+                return true;
+            }
+        }
+    }
+    false
 }
 
 impl Settings {
@@ -20,7 +34,8 @@ impl Settings {
         s.set_default("search_dirs", vec!["~/git/*"])?;
         s.set_default("preview_files", vec!["README.*"])?;
         s.set_default("preview", true)?;
-        s.set_default("preview_with_bat", false)?;
+        s.set_default("preview_with_bat", is_program_in_path("bat"))?;
+        s.set_default("preview_fallback_exa", is_program_in_path("exa"))?;
 
         let home = home_dir();
         if home.is_none() {
@@ -29,16 +44,20 @@ impl Settings {
 
         // merge user config if it exists
         let home = home.unwrap();
-        let user_config_path: PathBuf = [
-            home.to_str().expect("Failed to determine config directory"),
-            ".config",
-            "ctrlg",
-            "config.yml",
-        ]
-        .iter()
-        .collect();
-        if user_config_path.exists() {
-            s.merge(File::with_name(user_config_path.to_str().unwrap()))?;
+        for config_file_name in CONFIG_FILE_NAMES.iter() {
+            let user_config_path: PathBuf = [
+                home.to_str().expect("Failed to determine config directory"),
+                ".config",
+                "ctrlg",
+                config_file_name,
+            ]
+            .iter()
+            .collect();
+
+            if user_config_path.exists() {
+                s.merge(File::with_name(user_config_path.to_str().unwrap()))?;
+                break;
+            }
         }
 
         s.try_into()
